@@ -109,14 +109,24 @@ cl_class_ids.bclust <- cl_class_ids.kmeans
 
 ## Package flexclust: kcca() returns objects of S4 class "kcca" which
 ## extends S4 class "flexclust".
+## <NOTE>
+## We used to be able to call flexclust::cluster(), but this now only
+## has S4 methods for modeltools::cluster() S4 generic.  Let's call this
+## one, and hope that flexclust has been loaded ...
+## </NOTE>
 cl_class_ids.kcca <-
 function(x)
-    as.cl_class_ids(flexclust::cluster(x))
+    as.cl_class_ids(modeltools::cluster(x))
 
 ## Package flexmix: class "flexmix".
+## <NOTE>
+## We used to be able to call flexmix::cluster(), but this now only has
+## S4 methods for modeltools::cluster() S4 generic.  Let's call this
+## one, and hope that flexmix has been loaded ...
+## </NOTE>
 cl_class_ids.flexmix <-
 function(x)
-    as.cl_class_ids(flexmix::cluster(x))
+    as.cl_class_ids(modeltools::cluster(x))
 
 ## Package kernlab: specc() and kkmeans() return objects of S4 class
 ## "specc".
